@@ -1,10 +1,29 @@
 # Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
-package Tk::Widget;
+package Tk::Clipboard; 
+use strict;
 
 use vars qw($VERSION);
-$VERSION = '3.004'; # $Id: //depot/Tk8/Tk/Clipboard.pm#4$
+$VERSION = '3.006'; # $Id: //depot/Tk8/Tk/Clipboard.pm#6$
+
+use AutoLoader qw(AUTOLOAD);
+use Tk qw(catch);
+
+sub clipEvents
+{
+ return qw[Copy Cut Paste];
+}
+
+sub ClassInit
+{
+ my ($class,$mw) = @_;
+ foreach my $op ($class->clipEvents)
+  {
+   $mw->Tk::bind($class,"<<$op>>","clipboard$op");
+  }
+ return $class;
+}
 
 sub clipboardSet
 {
@@ -45,21 +64,10 @@ sub clipboardPaste
 {
  my $w = shift;
  local $@;
- eval {local $SIG{__DIE__}; $w->insert("insert",$w->clipboardGet)};
+ catch { $w->insert("insert",$w->clipboardGet)};
 }
 
-# clipboardKeysyms --
-# This procedure is invoked to identify the keys that correspond to
-# the "copy", "cut", and "paste" functions for the clipboard.
-#
-# Arguments:
-# copy - Name of the key (keysym name plus modifiers, if any,
-# such as "Meta-y") used for the copy operation.
-# cut - Name of the key used for the cut operation.
-# paste - Name of the key used for the paste operation.
-
-
-sub clipboardKeysyms
+sub clipboardOperations
 {
  my @class = (); 
  my $mw    = shift;
@@ -72,20 +80,9 @@ sub clipboardKeysyms
    push(@class,$mw);
    $mw = shift;
   }
- if (@_)
+ while (@_)
   {
-   my $copy  = shift;
-   $mw->Tk::bind(@class,"<$copy>",'clipboardCopy')   if (defined $copy);
-  }
- if (@_)
-  {
-   my $cut   = shift;
-   $mw->Tk::bind(@class,"<$cut>",'clipboardCut')     if (defined $cut);
-  }
- if (@_)
-  {
-   my $paste = shift;                                                
-   $mw->Tk::bind(@class,"<$paste>",'clipboardPaste') if (defined $paste);
+   my $op = shift;
   }
 }
 
@@ -95,9 +92,13 @@ sub clipboardKeysyms
 sub deleteSelected
 {
  my $w = shift;
- Tk::catch { $w->delete('sel.first','sel.last') };
+ catch { $w->delete('sel.first','sel.last') };
 }
 
+
+1;
+__END__
+
 sub getSelected
 {
  my $w   = shift;
@@ -106,5 +107,3 @@ sub getSelected
 }
 
 
-1;
-__END__
