@@ -1,7 +1,7 @@
 package Tk::Dialog;
 
 use vars qw($VERSION);
-$VERSION = '3.011'; # $Id: //depot/Tk8/Tk/Dialog.pm#11$
+$VERSION = '3.013'; # $Id: //depot/Tk8/Tk/Dialog.pm#13$
 
 # Dialog - a translation of `tk_dialog' from Tcl/Tk to TkPerl (based on
 # John Stoffel's idea).
@@ -9,8 +9,6 @@ $VERSION = '3.011'; # $Id: //depot/Tk8/Tk/Dialog.pm#11$
 # Stephen O. Lidie, Lehigh University Computing Center.  94/12/27
 # lusol@Lehigh.EDU
 
-# Documentation after __END__
-
 use Carp;
 use strict;
 
@@ -19,14 +17,12 @@ require Tk::Toplevel;
 
 Construct Tk::Widget 'Dialog';
 
-sub Populate
-{
+sub Populate {
 
     # Dialog object constructor.  Uses `new' method from base class
     # to create object container then creates the dialog toplevel.
 
     my($cw, $args) = @_;
-
     $cw->SUPER::Populate($args);
 
     my ($w_bitmap,$w_but,$pad1,$pad2);
@@ -35,8 +31,8 @@ sub Populate
     $buttons = ['OK'] unless (defined $buttons);
     my $default_button = delete $args->{-default_button};
     $default_button =  $buttons->[0] unless (defined $default_button);
+    $cw->{-default_button_text} = $default_button;
 
-    
     # Create the Toplevel window and divide it into top and bottom parts.
 
     $cw->{'selected_button'} = '';
@@ -53,6 +49,7 @@ sub Populate
     my $w_bot = $cw->Frame(Name => 'bot',-relief => 'raised', -borderwidth => 1);
     $w_top->pack(@pl);
     $w_bot->pack(@pl);
+    $cw->Advertise(-buttons_frame => $w_bot);
 
     # Fill the top part with the bitmap and message.
 
@@ -65,9 +62,35 @@ sub Populate
 
     $w_msg->pack(-side => 'right', -expand => 1, -fill => 'both', @$pad1);
 
+    $cw->Advertise(message => $w_msg);
+    $cw->Advertise(bitmap  => $w_bitmap );
+
+    $cw->ConfigSpecs(
+                      -buttons    => ['METHOD', 'buttons', 'Buttons', ['OK']],
+                      -image      => ['bitmap',undef,undef,undef],
+                      -bitmap     => ['bitmap',undef,undef,undef],
+                      -fg         => ['ADVERTISED','foreground','Foreground','black'],
+                      -foreground => ['ADVERTISED','foreground','Foreground','black'],
+                      -bg         => ['DESCENDANTS','background','Background',undef],
+                      -background => ['DESCENDANTS','background','Background',undef],
+                      -font       => ['message','font','Font', '-*-Times-Medium-R-Normal--*-180-*-*-*-*-*-*'],
+                      DEFAULT     => ['message',undef,undef,undef]
+                     );
+    $cw->Delegates('Construct' => $w_top);
+
+} # end Dialog constructor
+
+sub buttons {
+
     # Create a row of buttons at the bottom of the dialog.
 
+    my($cw, $buttons) = @_;
+
     my($w_default_button, $bl) = (undef, '');
+    my $w_bot = $cw->Subwidget(-buttons_frame);
+    my (@pl) = (-side => 'left');
+    my $pad2 = [-padx => '3m', -pady => '2m'];
+    my($w_but);
     foreach $bl (@$buttons) {
         $w_but = $w_bot->Button(
             -text => $bl,
@@ -77,7 +100,7 @@ sub Populate
                 }, $cw, $bl,
             ]
         );
-        if ($bl eq $default_button) {
+        if ($bl eq $cw->{-default_button_text}) {
             $w_default_button = $w_bot->Frame(
                 -relief      => 'sunken',
                 -borderwidth => 1
@@ -98,23 +121,9 @@ sub Populate
          $w_but->pack(@pl, -expand => 1, @$pad2);
         }
     } # forend all buttons
-
-    $cw->Advertise(message => $w_msg);
-    $cw->Advertise(bitmap  => $w_bitmap );
     $cw->{'default_button'} = $w_default_button;
 
-    $cw->ConfigSpecs(
-                      -image      => ['bitmap',undef,undef,undef],
-                      -bitmap     => ['bitmap',undef,undef,undef],
-                      -fg         => ['ADVERTISED','foreground','Foreground','black'],
-                      -foreground => ['ADVERTISED','foreground','Foreground','black'],
-                      -bg         => ['DESCENDANTS','background','Background',undef],
-                      -background => ['DESCENDANTS','background','Background',undef],
-                      -font       => ['message','font','Font', '-*-Times-Medium-R-Normal--*-180-*-*-*-*-*-*'],
-                      DEFAULT     => ['message',undef,undef,undef]
-                     );
-    $cw->Delegates('Construct' => $w_top);
-} # end Dialog constructor
+} # end buttons
 
 sub Show {
 
@@ -164,8 +173,3 @@ sub Show {
 } # end Dialog Show method
 
 1;
-
-__END__
-
-=cut
-
