@@ -21,6 +21,8 @@
 #endif
 
 
+#include "tk.h"
+#include "tkVMacro.h"
 #include "imgInt.h"
 #include <string.h>
 
