@@ -9,7 +9,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkConfig.c,v 1.2 1998/09/14 18:23:08 stanton Exp $
+ * SCCS: @(#) tkConfig.c 1.53 96/04/26 10:29:31
  */
 
 #include "tkPort.h"
@@ -125,14 +125,7 @@ Tk_ConfigureWidget(interp, tkwin, specs, argc, argv, widgRec, flags)
      */
 
     for ( ; argc > 0; argc -= 2, argv += 2) {
-	char *arg;
-
-	if (flags & TK_CONFIG_OBJS) {
-	    arg = Tcl_GetStringFromObj(*args, NULL);
-	} else {
-	    arg = *argv;
-	}
-	specPtr = FindConfigSpec(interp, specs, arg, needFlags, hateFlags);
+	specPtr = FindConfigSpec(interp, specs, *argv, needFlags, hateFlags);
 	if (specPtr == NULL) {
 	    if (!(flags & TK_CONFIG_ARGV_ONLY)) {
 		/*
@@ -155,18 +148,10 @@ Tk_ConfigureWidget(interp, tkwin, specs, argc, argv, widgRec, flags)
 	 */
 
 	if (argc < 2) {
-	    Tcl_AppendResult(interp, "value for \"", arg,
+	    Tcl_AppendResult(interp, "value for \"", *argv,
 		    "\" missing", (char *) NULL);
 	    return TCL_ERROR;
 	}
-#if 0 /* DASH PATCH */
-	if (flags & TK_CONFIG_OBJS) {
-	    arg = Tcl_GetStringFromObj(args[1], NULL);
-	} else {
-	    arg = argv[1];
-	}
-	if (DoConfig(interp, tkwin, specPtr, arg, 0, widgRec) != TCL_OK) { }
-#endif /* DASH PATCH */
 	if (DoConfig(interp, tkwin, specPtr, args[1], widgRec) != TCL_OK) {
 	    char msg[100];
 
@@ -521,9 +506,7 @@ DoConfig(interp, tkwin, specPtr, value, widgRec)
 	    case TK_CONFIG_BITMAP: {
 		Pixmap new, old;
 
-		if (nullValue || 
-		   (( specPtr->specFlags & TK_CONFIG_NULL_OK) && 
-                      !*LangString(value)))  {
+		if (nullValue) {
 		    new = None;
 	        } else {
 		    uid = Tk_GetUid(LangString(value));
@@ -898,7 +881,7 @@ FormatConfigValue(interp, tkwin, specPtr, widgRec, freeProcPtr)
 	case TK_CONFIG_FONT: {
 	    Tk_Font tkfont = *((Tk_Font *) ptr);
 	    if (tkfont != NULL) {
-		LangSetArg(&result, LangFontArg(interp, tkfont, NULL));
+		LangSetArg(&result, LangFontArg(interp, tkfont));
 	    }
 	    break;
 	}
