@@ -5,30 +5,16 @@
  *
  * Copyright (c) 1995-1996 Sun Microsystems, Inc.
  * Copyright (c) 1994 Software Research Associates, Inc.
- * Copyright (c) 1998 by Scriptics Corporation.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkWinX.c,v 1.4 1998/10/10 00:30:37 rjohnson Exp $
+ * SCCS: @(#) tkWinX.c 1.51 97/09/02 13:06:57
  */
 
 #include "tkInt.h"
 #include "tkWinInt.h"
 
-/*
- * The zmouse.h file includes the definition for WM_MOUSEWHEEL.
- */
-
-#ifndef __GNUC__       // not in Minw32 yet
-#include <zmouse.h>
-#endif
-#ifndef WM_MOUSEWHEEL
-#define WM_MOUSEWHEEL (WM_MOUSELAST+1)  // message that will be supported
-                                        // by the OS 
-#endif
-
-
 /*
  * Definitions of extern variables supplied by this file.
  */
@@ -110,20 +96,6 @@ TkGetServerInfo(interp, tkwin)
  *----------------------------------------------------------------------
  */
 
-static BOOL CALLBACK 
-FindMyConsole( HWND win, LPARAM arg )
-{
- DWORD mypid = *((DWORD *) arg);
- DWORD pid;
- GetWindowThreadProcessId(win,&pid);
- if (pid == mypid)
-  {
-   ShowWindow(win,SW_SHOWMINNOACTIVE);
-  }
- return TRUE;
-}
-
-
 HINSTANCE
 Tk_GetHINSTANCE()
 {
@@ -151,12 +123,10 @@ TkWinXInit(hInstance)
     HINSTANCE hInstance;
 {
     OSVERSIONINFO info;
-    DWORD mypid = GetCurrentProcessId();
 
     info.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
     GetVersionEx(&info);
     tkpIsWin32s = (info.dwPlatformId == VER_PLATFORM_WIN32s);
-    EnumWindows(FindMyConsole, (LPARAM) &mypid);
 
     if (childClassInitialized != 0) {
 	return;
@@ -473,36 +443,6 @@ XBell(display, percent)
     MessageBeep(MB_OK);
 }
 
-/*
- *----------------------------------------------------------------------
- *
- * XLowerWindow --
- *
- *	Change the stacking order of a window.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	Changes the stacking order of the specified window.
- *
- *----------------------------------------------------------------------
- */
-
-#if 0 /* Better one in tkWinWindow.c */
-void
-XLowerWindow(display, w)
-    Display* display;
-    Window w;
-{
-    HWND window = TkWinGetHWND(w);
-
-    display->request++;
-    SetWindowPos(window, HWND_TOPMOST, 0, 0, 0, 0,
-	    SWP_NOMOVE | SWP_NOSIZE);
-}
-#endif
-
 /*
  *----------------------------------------------------------------------
  *
@@ -600,15 +540,6 @@ Tk_TranslateWinEvent(hwnd, message, wParam, lParam, resultPtr)
 {
     *resultPtr = 0;
     switch (message) {
-        default: {
-	    Tk_Window tkwin = (Tk_Window) Tk_HWNDToWindow(hwnd);
-	    if (tkwin) {
-		if (Lang_WinEvent(tkwin, message, wParam, lParam, resultPtr))
-	  	    return 1;
-            }
-	    break;
-        }
-
 	case WM_RENDERFORMAT: {
 	    TkWindow *winPtr = (TkWindow *) Tk_HWNDToWindow(hwnd);
 	    if (winPtr) {
@@ -660,14 +591,8 @@ Tk_TranslateWinEvent(hwnd, message, wParam, lParam, resultPtr)
 	case WM_SYSKEYUP:
 	case WM_KEYDOWN:
 	case WM_KEYUP:
-	case WM_MOUSEWHEEL:
  	    GenerateXEvent(hwnd, message, wParam, lParam);
 	    return 1;
-	case WM_MENUCHAR:
-	    GenerateXEvent(hwnd, message, wParam, lParam);
-	    /* MNC_CLOSE is the only one that looks right.  This is a hack. */
-	    *resultPtr = MAKELONG (0, MNC_CLOSE);
-	    return 1;
     }
     return 0;
 }
@@ -772,13 +697,6 @@ GenerateXEvent(hwnd, message, wParam, lParam)
 	    event.xselectionclear.time = TkpGetMS();
 	    break;
 	    
-	case WM_MOUSEWHEEL:
-	    /*
-	     * The mouse wheel event is closer to a key event than a
-	     * mouse event in that the message is sent to the window
-	     * that has focus.
-	     */
-	    
 	case WM_CHAR:
 	case WM_SYSKEYDOWN:
 	case WM_SYSKEYUP:
@@ -820,18 +738,6 @@ GenerateXEvent(hwnd, message, wParam, lParam)
 	     */
 
 	    switch (message) {
-		case WM_MOUSEWHEEL:
-		    /*
-		     * We have invented a new X event type to handle
-		     * this event.  It still uses the KeyPress struct.
-		     * However, the keycode field has been overloaded
-		     * to hold the zDelta of the wheel.
-		     */
-		    
-		    event.type = MouseWheelEvent;
-		    event.xany.send_event = -1;
-		    event.xkey.keycode = (short) HIWORD(wParam);
-		    break;
 		case WM_SYSKEYDOWN:
 		case WM_KEYDOWN:
 		    /*
@@ -1000,22 +906,13 @@ GetTranslatedKey(xkey)
 
     while (xkey->nchars < XMaxTransChars
 	    && PeekMessage(&msg, NULL, 0, 0, PM_NOREMOVE)) {
-	if ((msg.message == WM_CHAR) || (msg.message == WM_SYSCHAR)) {
+	if (msg.message == WM_CHAR) {
 	    xkey->trans_chars[xkey->nchars] = (char) msg.wParam;
 #ifdef __OPEN32__
 	    StashedKey = (char) msg.wParam;
 #endif
 	    xkey->nchars++;
 	    GetMessage(&msg, NULL, 0, 0);
-
-	    /*
-	     * If this is a normal character message, we may need to strip
-	     * off the Alt modifier (e.g. Alt-digits).  Note that we don't
-	     * want to do this for system messages, because those were
-	     * presumably generated as an Alt-char sequence (e.g. accelerator
-	     * keys).
-	     */
-
 	    if ((msg.message == WM_CHAR) && (msg.lParam & 0x20000000)) {
 		xkey->state = 0;
 	    }
